@@ -16,9 +16,9 @@ def findAndDrawFacesVanilla(frame):
     Create a grayscaled version of the image, find the faces, and draw them on the original image
     All using vanilla facial detection that came with opencv
     """
-    package_directory = os.path.dirname(__file__)
-    path = os.path.join(package_directory, "classifier\haarcascade_frontalface_default.xml")\
-
+    # package_directory = os.path.dirname(__file__)
+    # path = os.path.join(package_directory, "classifier\haarcascade_frontalface_default.xml")
+    path = os.path.join(os.getcwd(), "classifier/hasarcascade_frontalface_default.xml")
     print(path +" ------------------------------------------------------------")
     haar_cascasde_face = cv.CascadeClassifier(path)
 
